About the name
==============

* nose is the least silly short synonym for discover in the dictionary.com
  thesaurus that does not contain the word 'spy.'
* Pythons have noses
* The nose knows where to find your tests
* Nose Obviates Suite Employment

Contact the author
==================

To report bugs, ask questions, or request features, please use the *issues*
tab at the GitHub site: https://github.com/atsb/nose-py3
Patches are welcome!

Similar test runners
====================

nose was inspired mainly by py.test_, which is a great test runner, but
formerly was not all that easy to install, and is not based on unittest.

Test suites written for use with nose should work equally well with py.test,
and vice versa, except for the differences in output capture and command line
arguments for the respective tools.

.. _py.test: http://codespeak.net/py/current/doc/test.html

License and copyright
=====================

nose is copyright Jason Pellerin 2005-2009
nose-py3 is copyright Jason Pellerin 2005-2009, Adam Bilbrough 2020-2023

This program is free software; you can redistribute it and/or modify it
under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation; either version 2 of the License, or (at your
option) any later version.

This program is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
License for more details.

You should have received a copy of the GNU Lesser General Public License
along with this program; if not, write to the Free Software Foundation,
Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
